package org.gcube.portlets.user.geoportaldataviewer.client.events;

import org.gcube.application.geoportalcommon.shared.geoportal.geojson.GeoJSON;

import com.google.gwt.event.shared.GwtEvent;

/**
 * The Class ShowDetailsEvent.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR francesco.mangiacrapa@isti.cnr.it
 * 
 *         Jul 30, 2021
 */
public class ShowPopupOnCentroiEvent extends GwtEvent<ShowPopupOnCentroiEventHandler> {
	public static Type<ShowPopupOnCentroiEventHandler> TYPE = new Type<ShowPopupOnCentroiEventHandler>();
	private String profileID;
	private String projectID;
	private GeoJSON spatialReference;

	/**
	 * Instantiates a new show details event.
	 *
	 * @param geonaItemType the geona item type
	 * @param geonaMongoID  the geona mongo ID
	 * @param itemName      the item name
	 * @param featureRow    the feature row
	 */
	public ShowPopupOnCentroiEvent(String profileID, String projectID, GeoJSON spatialReference) {
		this.profileID = profileID;
		this.projectID = projectID;
		this.spatialReference = spatialReference;

	}

	/**
	 * Gets the associated type.
	 *
	 * @return the associated type
	 */
	@Override
	public Type<ShowPopupOnCentroiEventHandler> getAssociatedType() {
		return TYPE;
	}

	/**
	 * Dispatch.
	 *
	 * @param handler the handler
	 */
	@Override
	protected void dispatch(ShowPopupOnCentroiEventHandler handler) {
		handler.onShowPopup(this);

	}

	public String getProfileID() {
		return profileID;
	}

	public String getProjectID() {
		return projectID;
	}

	public GeoJSON getSpatialReference() {
		return spatialReference;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("ShowPopupOnCentroiEvent [profileID=");
		builder.append(profileID);
		builder.append(", projectID=");
		builder.append(projectID);
		builder.append(", spatialReference=");
		builder.append(spatialReference);
		builder.append("]");
		return builder.toString();
	}

}